@@ -280,8 +280,9 @@ coxreg <- function (formula = formula(data),
                 if (is.null(init))
                     temp <- fit$coef[nabeta]
                 else temp <- (fit$coef - init)[nabeta]
-                fit$wald.test <- survival:::coxph.wtest(fit$var[nabeta, nabeta],
-                                                        temp, control$toler.chol)$test
+                fit$wald.test <-
+                    survival:::coxph.wtest(fit$var[nabeta, nabeta],
+                                           temp, control$toler.chol)$test
             }
         }
         na.action <- attr(m, "na.action")
@@ -295,6 +296,7 @@ coxreg <- function (formula = formula(data),
                 fit$strata <- strata.keep
         }
     }
+    fit$stratum <- strats
     if (y)
         fit$y <- Y
     if (x)
@@ -306,7 +308,11 @@ coxreg <- function (formula = formula(data),
 
     fit$isF <- isF
     fit$covars <- covars
-    s.wght <- (Y[, 2] - Y[, 1])## * weights
+    if (NCOL(Y) == 3){
+        s.wght <- (Y[, 2] - Y[, 1])## * weights
+    }else{
+        s.wght <- Y[, 1]
+    }
     fit$ttr <- sum(s.wght)
     fit$w.means <- list()
     if (length(fit$covars)){
@@ -336,6 +342,9 @@ coxreg <- function (formula = formula(data),
         names(fit$coefficients) <- colnames(X)
         fit$means <- apply(X, 2, mean)
     }
+    if (length(strats)){
+        fit$strata <- levels(as.factor(strata.keep)) ## New 2.2-6
+    }
     fit$method <- method
     fit$n <- NROW(Y)
     fit$df <- length(fit$coefficients)
